/*
 * libDebug
 *
 * Copyright (C) 2000 Patrick Alken
 * This library comes with absolutely NO WARRANTY
 *
 * Should you choose to use and/or modify this source code, please
 * do so under the terms of the GNU General Public License under which
 * this program is distributed.
 *
 * $Id: args.h,v 1.1.1.1 2004/04/26 00:41:11 pa33 Exp $
 */

#ifndef INCLUDED_libDebug_args_h
#define INCLUDED_libDebug_args_h

/*
 * Prototypes
 */

int SplitArgs(char *buffer, char ***array);

#endif /* INCLUDED_libDebug_args_h */
